from pathlib import Path
from .markdown_to_html import MarkdownToHtml

import harrixpylib as h

class Dir_md_to_dir_html:
    def __init__(self, markdown_path, output_path):
        self.markdown_path = Path(markdown_path).resolve()
        self.output_path = Path(output_path).resolve()
        print(self.output_path)

    def start(self):
        for item in self.markdown_path.rglob("*.md"):
            parts = list(item.parts[len(self.markdown_path.parts)::])
            if len(item.suffixes) == 1:
                parts[-1] = 'ru'
            else:
                parts[-1] = item.suffixes[-2][1:]
            MarkdownToHtml(item, self.output_path.joinpath(*parts)).start()



from .dir_md_to_dir_html import Dir_md_to_dir_html

import harrixpylib as h

class StaticSiteGenerator:
    def __init__(self, markdown_paths, output_path):
        self.markdown_paths = markdown_paths
        self.output_path = output_path

    def start(self):
        h.clear_directory(self.output_path)
        for path in self.markdown_paths:
            Dir_md_to_dir_html(path, self.output_path).start()


from setuptools import setup

setup(name='harrix-pyssg',
      version='0.1',
      description='Static site generator',
      packages=['harrixpyssg'],
      author_email='anton.b.sergienko@gmail.com',
      zip_safe=False)


from pathlib import Path
import shutil
import markdown

import harrixpylib as h


class MarkdownToHtml:
    def __init__(self, markdown_filename, output_path):
        self.markdown_filename = Path(markdown_filename)
        self.output_path = Path(output_path)

    def start(self):
        h.clear_directory(self.output_path)

        markdown_text = h.open_file(self.markdown_filename)

        md = markdown.Markdown(extensions=['meta'])
        html = md.convert(markdown_text)

        self.copy_dirs()

        h.save_file(html, self.output_path / 'index.html')

    def copy_dirs(self):
        dirs_of_files = ['img', 'files', 'demo', 'gallery']
        for d in dirs_of_files:
            self.copy_dir(d)

    def copy_dir(self, directory):
        path_img = self.markdown_filename.parent / directory
        if path_img.is_dir():
            shutil.copytree(path_img, self.output_path /
                            directory, dirs_exist_ok=True)
